@@ -16,10 +16,8 @@ for which a new license (GPL+exception) is in place.
 #include <QStack>
 #include <QStack>
 
-#include <cmath>
 #include <cstdlib>
 
-
 #include "commonstrings.h"
 #include "customfdialog.h"
 #include "importps.h"
@@ -219,6 +217,7 @@ bool EPSPlug::import(QString fName, const TransactionSettings &trSettings, int f
 	FPoint minSize = m_Doc->minCanvasCoordinate;
 	FPoint maxSize = m_Doc->maxCanvasCoordinate;
 	FPoint cOrigin = m_Doc->view()->canvasOrigin();
+	m_Doc->view()->Deselect();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
 	m_Doc->view()->updatesOn(false);
@@ -280,7 +279,6 @@ bool EPSPlug::import(QString fName, const TransactionSettings &trSettings, int f
 				m_Doc->Items->insert(lowestItem, neu);
 				neu->Groups.push(m_Doc->GroupCounter);
 				neu->setItemName( tr("Group%1").arg(neu->Groups.top()));
-				neu->AutoName = false;
 				neu->isGroupControl = true;
 				neu->groupsLastItem = high;
 				neu->setTextFlowMode(PageItem::TextFlowDisabled);
@@ -387,7 +385,7 @@ bool EPSPlug::convert(QString fn, double x, double y, double b, double h)
 	QString tmpFile = getShortPathName(ScPaths::getTempFileDir())+ "/ps.out";
 	QString errFile = getShortPathName(ScPaths::getTempFileDir())+ "/ps.err";
 	QString pfad = ScPaths::instance().libDir();
-	QString pfad2 = QDir::convertSeparators(pfad + "import.prolog");
+	QString pfad2 = QDir::toNativeSeparators(pfad + "import.prolog");
 	QFileInfo fi = QFileInfo(fn);
 	QString ext = fi.suffix().toLower();
 	
@@ -405,8 +403,8 @@ bool EPSPlug::convert(QString fn, double x, double y, double b, double h)
 	args.append( "-dSAFER" );
 	args.append( "-dDEVICEWIDTH=250000" );
 	args.append( "-dDEVICEHEIGHT=250000" );
-	args.append( QString("-sOutputFile=%1").arg(QDir::convertSeparators(cleanFile)) );
-	args.append( QDir::convertSeparators(fn) );
+	args.append( QString("-sOutputFile=%1").arg(QDir::toNativeSeparators(cleanFile)) );
+	args.append( QDir::toNativeSeparators(fn) );
 	System(getShortPathName(PrefsManager::instance()->ghostscriptExecutable()), args, errFile, errFile, &cancel);
 	args.clear();
 */
@@ -436,7 +434,7 @@ bool EPSPlug::convert(QString fn, double x, double y, double b, double h)
 	args.append( tmp.setNum(-x) );
 	args.append( tmp.setNum(-y) );
 	args.append( "translate" );
-	args.append( QString("-sTraceFile=%1").arg(QDir::convertSeparators(tmpFile)) );
+	args.append( QString("-sTraceFile=%1").arg(QDir::toNativeSeparators(tmpFile)) );
 	QString exportPath = m_Doc->DocName + "-" + fi.baseName();
 	QFileInfo exportFi(exportPath);
 	if ( !exportFi.isWritable() ) {
@@ -450,9 +448,9 @@ bool EPSPlug::convert(QString fn, double x, double y, double b, double h)
 		exportFi.setFile(docDir + "/" + exportFi.baseName());
 	}
 	//qDebug() << QString("using export path %1").arg(exportFi.absFilePath());
-	args.append( QString("-sExportFiles=%1").arg(QDir::convertSeparators(exportFi.absoluteFilePath())) );
+	args.append( QString("-sExportFiles=%1").arg(QDir::toNativeSeparators(exportFi.absoluteFilePath())) );
 	args.append( pfad2 );
-	args.append( QDir::convertSeparators(fn) );
+	args.append( QDir::toNativeSeparators(fn) );
 	args.append( "-c" );
 	args.append( "flush" );
 	args.append( "cfile" );
@@ -707,7 +705,6 @@ void EPSPlug::parseOutput(QString fn, bool eps)
 						}
 						ite->isGroupControl = true;
 						ite->setItemName( tr("Group%1").arg(m_Doc->GroupCounter));
-						ite->AutoName = false;
 						ite->setTextFlowMode(PageItem::TextFlowDisabled);
 						Elements.append(ite);
 						groupStack.push(ite);
@@ -743,7 +740,6 @@ void EPSPlug::parseOutput(QString fn, bool eps)
 							}
 							ite->isGroupControl = true;
 							ite->setItemName( tr("Group%1").arg(m_Doc->GroupCounter));
-							ite->AutoName = false;
 							ite->setTextFlowMode(PageItem::TextFlowDisabled);
 							Elements.append(ite);
 							groupStack.push(ite);
@@ -907,8 +903,8 @@ bool EPSPlug::Image(QString vals)
 	args.append( QString("-sDEVICE=%1").arg(device) );    
 	args.append( "-dBATCH" );
 	args.append( QString("-g%1x%2").arg(horpix).arg(verpix) );
-	args.append( QString("-sOutputFile=%1").arg(QDir::convertSeparators(filename)) );
-	args.append( QDir::convertSeparators(rawfile) );
+	args.append( QString("-sOutputFile=%1").arg(QDir::toNativeSeparators(filename)) );
+	args.append( QDir::toNativeSeparators(rawfile) );
 	args.append( "-c" );
 	args.append( "showpage" );
 	args.append( "quit" );
