@@ -14,7 +14,7 @@ for which a new license (GPL+exception) is in place.
 #include <QPainterPath>
 #include <QRegExp>
 #include <QTemporaryFile>
-#include <cmath>
+
 #include "color.h"
 #include "commonstrings.h"
 #include "customfdialog.h"
@@ -69,7 +69,7 @@ void svgimplugin_freePlugin(ScPlugin* plugin)
 }
 
 SVGImportPlugin::SVGImportPlugin() : LoadSavePlugin(),
-	importAction(new ScrAction(ScrAction::DLL, QPixmap(), QPixmap(), "", QKeySequence(), this))
+	importAction(new ScrAction(ScrAction::DLL, "", QKeySequence(), this))
 {
 	// Set action info in languageChange, so we only have to do
 	// it in one place. This includes registering file format
@@ -408,7 +408,6 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 			m_Doc->Items->insert(lowestItem, neu);
 			neu->Groups.push(m_Doc->GroupCounter);
 			neu->setItemName( tr("Group%1").arg(neu->Groups.top()));
-			neu->AutoName = false;
 			neu->isGroupControl = true;
 			neu->groupsLastItem = high;
 			for (int a = 0; a < m_Doc->Items->count(); ++a)
@@ -594,10 +593,7 @@ void SVGPlug::finishNode( const QDomNode &e, PageItem* item)
 	{
 		QString nodeId = e.toElement().attribute("id");
 		if( !nodeId.isEmpty() )
-		{
 			item->setItemName(" "+nodeId);
-			item->AutoName = false;
-		}
 	}
 	item->setFillTransparency( 1 - gc->FillOpacity * gc->Opacity );
 	item->setLineTransparency( 1 - gc->StrokeOpacity * gc->Opacity );
@@ -816,15 +812,15 @@ void SVGPlug::parseDefs(const QDomElement &e)
 		parseStyle( &svgStyle, b );
 		if ( !svgStyle.Display) 
 			continue;
-		QString STag2 = b.tagName();
-		if ( STag2 == "g" )
+		QString STag2 = parseTagName(b);
+		if (STag2 == "g" )
 		{
 			QString id = b.attribute("id", "");
 			if (!id.isEmpty())
 				m_nodeMap.insert(id, b);
 			parseDefs(b);
 		}
-		else if ( STag2 == "linearGradient" || STag2 == "radialGradient" )
+		else if (STag2 == "linearGradient" || STag2 == "radialGradient")
 			parseGradient( b );
 		else if (STag2 == "clipPath")
 			parseClipPath(b);
@@ -1018,7 +1014,6 @@ QList<PageItem*> SVGPlug::parseGroup(const QDomElement &e)
 			neu->setItemName(e.attribute("id"));
 		else
 			neu->setItemName( tr("Group%1").arg(neu->Groups.top()));
-		neu->AutoName = false;
 		neu->setFillTransparency(1 - gc->Opacity);
 		neu->gXpos = neu->xPos() - gx;
 		neu->gYpos = neu->yPos() - gy;
@@ -1046,53 +1041,53 @@ QList<PageItem*> SVGPlug::parseElement(const QDomElement &e)
 	QList<PageItem*> GElements;
 	if (e.hasAttribute("id"))
 		m_nodeMap.insert(e.attribute("id"), e);
-	QString STag = e.tagName();
-	if ( STag == "g" )
+	QString STag = parseTagName(e);
+	if (STag == "g")
 	{
 		GElements = parseGroup( e );
 		return GElements;
 	}
-	if ( STag == "defs" )
+	if (STag == "defs")
 		parseDefs(e);
-	else if ( STag == "a" )
+	else if (STag == "a")
 		GElements = parseA(e);
-	else if ( STag == "switch" )
+	else if (STag == "switch")
 		GElements = parseSwitch(e);
-	else if ( STag == "symbol" )
+	else if (STag == "symbol")
 		GElements = parseSymbol(e);
-	else if ( STag == "use" )
+	else if (STag == "use")
 		GElements = parseUse(e);
-	else if ( STag == "linearGradient" || STag == "radialGradient" )
+	else if (STag == "linearGradient" || STag == "radialGradient" )
 		parseGradient( e );
-	else if ( STag == "rect" )
+	else if (STag == "rect")
 		GElements = parseRect(e);
-	else if ( STag == "ellipse" )
+	else if (STag == "ellipse")
 		GElements = parseEllipse(e);
-	else if ( STag == "circle" )
+	else if (STag == "circle")
 		GElements = parseCircle(e);
-	else if ( STag == "line" )
+	else if (STag == "line")
 		GElements = parseLine(e);
-	else if ( STag == "path" )
+	else if (STag == "path")
 		GElements = parsePath(e);
-	else if ( STag == "polyline" || e.tagName() == "polygon" )
+	else if (STag == "polyline" || STag == "polygon")
 		GElements = parsePolyline(e);
-	else if ( STag == "text" )
+	else if (STag == "text")
 		GElements = parseText(e);
-	else if ( STag == "clipPath" )
+	else if (STag == "clipPath")
 		parseClipPath(e);
-	else if ( STag == "desc" )
+	else if (STag == "desc")
 	{
 		if (groupLevel == 1)
 			docDesc = e.text();
 	}
-	else if ( STag == "title" )
+	else if (STag == "title")
 	{
 		if (groupLevel == 1)
 			docTitle = e.text();
 	}
-	else if ( STag == "image" )
+	else if (STag == "image")
 		GElements = parseImage(e);
-/*	else if ( STag == "i:pgf" )
+/*	else if (STag == "i:pgf")
 	{
 		QByteArray cdat;
 		QByteArray ddat;
@@ -1165,7 +1160,7 @@ QList<PageItem*> SVGPlug::parseElement(const QDomElement &e)
 /*	else if( STag == "image" )
 		GElements = parseImage(e);
 	} */
-	else if (!isIgnorableNodeName(STag) )
+	else if (!isIgnorableNodeName(STag))
 	{
 		// warn if unsupported SVG feature are encountered
 		if (!m_unsupportedFeatures.contains(STag))
@@ -1339,10 +1334,10 @@ QList<PageItem*> SVGPlug::parsePolyline(const QDomElement &e)
 	QString points = e.attribute( "points" );
 	if (!points.isEmpty())
 	{
-		QString STag = e.tagName();
+		QString tagName = parseTagName(e);
 		points = points.simplified().replace(',', " ");
 		QStringList pointList = points.split( ' ', QString::SkipEmptyParts );
-		if (( e.tagName() == "polygon" ) && (pointList.count() > 4))
+		if ((tagName == "polygon" ) && (pointList.count() > 4))
 			z = m_Doc->itemAdd(PageItem::Polygon, PageItem::Unspecified, BaseX, BaseY, 10, 10, gc->LWidth, gc->FillCol, gc->StrokeCol, true);
 		else
 			z = m_Doc->itemAdd(PageItem::PolyLine, PageItem::Unspecified, BaseX, BaseY, 10, 10, gc->LWidth, gc->FillCol, gc->StrokeCol, true);
@@ -1369,7 +1364,7 @@ QList<PageItem*> SVGPlug::parsePolyline(const QDomElement &e)
 				ite->PoLine.svgLineTo(x, y);
 			}
 		}
-		if (( STag == "polygon" ) && (pointList.count() > 4))
+		if (( tagName == "polygon" ) && (pointList.count() > 4))
 			ite->PoLine.svgClosePath();
 		else
 			ite->convertTo(PageItem::PolyLine);
@@ -1423,7 +1418,7 @@ QList<PageItem*> SVGPlug::parseText(const QDomElement &e)
 		getTextChunkWidth(e, chunkWidth);
 	for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 	{
-		if (n.isElement() && (n.toElement().tagName() == "tspan"))
+		if (n.isElement() && (parseTagName(n.toElement()) == "tspan"))
 		{
 			QList<PageItem*> el = parseTextSpan(n.toElement(), currentPos, chunkWidth);
 			for (int ec = 0; ec < el.count(); ++ec)
@@ -1453,7 +1448,7 @@ QList<PageItem*> SVGPlug::parseTextSpan(const QDomElement& e, FPoint& currentPos
 	}
 	for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 	{
-		if (n.isElement() && (n.toElement().tagName() == "tspan"))
+		if (n.isElement() && (n.toElement().localName() == "tspan"))
 		{
 			QList<PageItem*> el = parseTextSpan(n.toElement(), currentPos, chunkW);
 			for (int ec = 0; ec < el.count(); ++ec)
@@ -1518,7 +1513,7 @@ QList<PageItem*> SVGPlug::parseSwitch(const QDomElement &e)
 	for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 	{
 		QDomElement de = n.toElement();
-		QString STag = de.tagName();
+		QString STag = parseTagName(de);
 		if (STag == "foreignObject")
 		{
 			if (de.hasAttribute("xlink:href"))
@@ -1581,7 +1576,7 @@ QList<PageItem*> SVGPlug::parseUse(const QDomElement &e)
 	if (it != m_nodeMap.end())
 	{
 		QDomElement elem = it.value().toElement();
-		if( elem.tagName() == "symbol" )
+		if (parseTagName(elem) == "symbol" )
 			UElements = parseGroup(elem);
 		else
 			UElements = parseElement(elem);
@@ -1699,7 +1694,7 @@ bool SVGPlug::getTextChunkWidth(const QDomElement &e, double& width)
 	QDomNode c = e.firstChild();
 	for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 	{
-		if (n.isElement() && (n.toElement().tagName() == "tspan"))
+		if (n.isElement() && (parseTagName(n.toElement()) == "tspan"))
 		{
 			QDomElement elem = n.toElement();
 			if (elem.hasAttribute("x") || elem.hasAttribute("y"))
@@ -2365,10 +2360,13 @@ void SVGPlug::parseStyle( SvgStyle *obj, const QDomElement &e )
 	QStringList substyles = style.split(';', QString::SkipEmptyParts);
 	for( QStringList::Iterator it = substyles.begin(); it != substyles.end(); ++it )
 	{
-		QStringList substyle = (*it).split(':', QString::SkipEmptyParts);
-		QString command(substyle[0].trimmed());
-		QString params(substyle[1].trimmed());
-		parsePA( obj, command, params );
+		QStringList substyle = it->split(':', QString::SkipEmptyParts);
+		if (substyle.count() >= 2)
+		{
+			QString command(substyle.at(0).trimmed());
+			QString params(substyle.at(1).trimmed());
+			parsePA( obj, command, params );
+		}
 	}
 	return;
 }
@@ -2384,7 +2382,7 @@ void SVGPlug::parseColorStops(GradientHelper *gradient, const QDomElement &e)
 	{
 		opa = 1.0;
 		QDomElement stop = n.toElement();
-		if(stop.tagName() == "stop")
+		if (parseTagName(stop) == "stop")
 		{
 			QString temp = stop.attribute( "offset" );
 			if( temp.contains( '%' ) )
@@ -2409,13 +2407,16 @@ void SVGPlug::parseColorStops(GradientHelper *gradient, const QDomElement &e)
 				QStringList substyles = style.split(';', QString::SkipEmptyParts);
 				for( QStringList::Iterator it = substyles.begin(); it != substyles.end(); ++it )
 				{
-					QStringList substyle = (*it).split(':', QString::SkipEmptyParts);
-					QString command(substyle[0].trimmed());
-					QString params(substyle[1].trimmed());
-					if( command == "stop-color" )
-						Col = parseColor(params);
-					if( command == "stop-opacity" )
-						opa = fromPercentage(params);
+					QStringList substyle = it->split(':', QString::SkipEmptyParts);
+					if (substyle.count() >= 2)
+					{
+						QString command(substyle.at(0).trimmed());
+						QString params(substyle.at(1).trimmed());
+						if( command == "stop-color" )
+							Col = parseColor(params);
+						if( command == "stop-opacity" )
+							opa = fromPercentage(params);
+					}
 				}
 			}
 		}
@@ -2543,7 +2544,8 @@ void SVGPlug::parseGradient( const QDomElement &e )
 		}
 		gradhelper.reference = href;
 	}
-	if (e.tagName() == "linearGradient")
+	QString tagName = parseTagName(e);
+	if (tagName == "linearGradient")
 	{
 		if (e.hasAttribute("x1"))
 		{
@@ -2628,6 +2630,14 @@ void SVGPlug::parseGradient( const QDomElement &e )
 	m_gradients.insert(e.attribute("id"), gradhelper);
 }
 
+QString SVGPlug::parseTagName(const QDomElement& element)
+{
+	QString tagName(element.tagName());
+	if (tagName.startsWith("svg:"))
+		return tagName.mid(4, -1);
+	return tagName;
+}
+
 SVGPlug::~SVGPlug()
 {
 	delete tmpSel;
