@@ -10,6 +10,7 @@ for which a new license (GPL+exception) is in place.
 #include <QString>
 #include <QDir>
 #include <QCursor>
+#include <QSharedPointer>
 
 #include "scmessagebox.h"
 #include "scribus.h"
@@ -94,8 +95,8 @@ bool PixmapExportPlugin::run(ScribusDoc* doc, QString target)
 {
 	Q_ASSERT(target.isEmpty());
 	Q_ASSERT(!doc->masterPageMode());
-	ExportBitmap *ex = new ExportBitmap();
-	ExportForm *dia = new ExportForm(doc->scMW(), doc, ex->pageDPI, ex->quality, ex->bitmapType);
+	QSharedPointer<ExportBitmap> ex( new ExportBitmap() );
+	QSharedPointer<ExportForm>  dia( new ExportForm(doc->scMW(), doc, ex->pageDPI, ex->quality, ex->bitmapType) );
 
 	// interval widgets handling
 	QString tmp;
@@ -144,9 +145,6 @@ bool PixmapExportPlugin::run(ScribusDoc* doc, QString target)
 		if (res)
 			doc->scMW()->setStatusBarInfoText( tr("Export successful"));
 	}
-	// clean the trash
-	delete ex;
-	delete dia;
 	return true;
 }
 
@@ -163,7 +161,7 @@ ExportBitmap::ExportBitmap()
 
 QString ExportBitmap::getFileName(ScribusDoc* doc, uint pageNr)
 {
-	return QDir::cleanPath(QDir::convertSeparators(exportDir + "/" + getFileNameByPage(doc, pageNr, bitmapType.toLower())));
+	return QDir::cleanPath(QDir::toNativeSeparators(exportDir + "/" + getFileNameByPage(doc, pageNr, bitmapType.toLower())));
 }
 
 ExportBitmap::~ExportBitmap()
@@ -198,7 +196,7 @@ bool ExportBitmap::exportPage(ScribusDoc* doc, uint pageNr, bool single = true)
 	if (QFile::exists(fileName) && !overwrite)
 	{
 		doFileSave = false;
-		QString fn = QDir::convertSeparators(fileName);
+		QString fn = QDir::toNativeSeparators(fileName);
 //		QApplication::restoreOverrideCursor();
 		QApplication::changeOverrideCursor(Qt::ArrowCursor);
 		over = QMessageBox::question(doc->scMW(), tr("File exists. Overwrite?"),
