@@ -28,7 +28,7 @@ for which a new license (GPL+exception) is in place.
 #include <QBuffer>
 #include <QList>
 #include <QCheckBox>
-#include <QSharedPointer>
+#include <QScopedPointer>
 
 #include "svgexplugin.h"
 
@@ -125,7 +125,7 @@ bool SVGExportPlugin::run(ScribusDoc* doc, QString filename)
 	{
 		PrefsContext* prefs = PrefsManager::instance()->prefsFile->getPluginContext("svgex");
 		QString wdir = prefs->get("wdir", ".");
-		QSharedPointer<CustomFDialog> openDia( new CustomFDialog(doc->scMW(), wdir, QObject::tr("Save as"), QObject::tr("%1;;All Files (*)").arg(FormatsManager::instance()->extensionsForFormat(FormatsManager::SVG)), fdHidePreviewCheckBox) );
+		QScopedPointer<CustomFDialog> openDia( new CustomFDialog(doc->scMW(), wdir, QObject::tr("Save as"), QObject::tr("%1;;All Files (*)").arg(FormatsManager::instance()->extensionsForFormat(FormatsManager::SVG)), fdHidePreviewCheckBox) );
 		openDia->setSelection(getFileNameByPage(doc, doc->currentPage()->pageNr(), "svg"));
 		openDia->setExtension("svg");
 		openDia->setZipExtension("svgz");
@@ -158,7 +158,6 @@ bool SVGExportPlugin::run(ScribusDoc* doc, QString filename)
 		Options.inlineImages = inlineImages->isChecked();
 		Options.exportPageBackground = exportBack->isChecked();
 		Options.compressFile = compress->isChecked();
-		openDia.clear();
 
 		if (fileName.isEmpty())
 			return true;
@@ -680,7 +679,7 @@ QDomElement SVGExPlug::processTextItem(PageItem *Item, QString trans, QString fi
 				sca.translate(Item->xPos(), Item->yPos());
 				finalMat *= sca;
 			}
-			if ((hl->ch == SpecialChars::OBJECT) && (hl->embedded.hasItem()))
+			if (hl->hasObject())
 			{
 				ob.appendChild(processInlineItem(CurX + hl->glyph.xoffset, ls.y + hl->glyph.yoffset, finalMat, hl, false, trans));
 				InlineFrame& embedded(const_cast<InlineFrame&>(hl->embedded));
@@ -910,7 +909,7 @@ QDomElement SVGExPlug::processPathTextItem(PageItem *Item, QString trans, QStrin
 			else
 				trafo *= QMatrix( a, 6 * b, 0, -1, hl->PtransX, hl->PtransY );
 		}
-		if ((hl->ch == SpecialChars::OBJECT) && (hl->embedded.hasItem()))
+		if (hl->hasObject())
 		{
 			QMatrix finalMat = QMatrix(chma * chma2 * chma3 * chma4 * chma6 * trafo);
 			ob.appendChild(processInlineItem(0, 0, finalMat, hl, true, trans));
