@@ -655,17 +655,17 @@ int PPreview::RenderPreview(int Seite, int Res)
 	PrefsTable *extraFonts = pc->getTable("ExtraFontDirs");
 	const char sep = ScPaths::envPathSeparator;
 	if (extraFonts->getRowCount() >= 1)
-		cmd1 = QString("-sFONTPATH=%1").arg(QDir::convertSeparators(extraFonts->get(0,0)));
+		cmd1 = QString("-sFONTPATH=%1").arg(QDir::toNativeSeparators(extraFonts->get(0,0)));
 	for (int i = 1; i < extraFonts->getRowCount(); ++i)
-		cmd1 += QString("%1%2").arg(sep).arg(QDir::convertSeparators(extraFonts->get(i,0)));
+		cmd1 += QString("%1%2").arg(sep).arg(QDir::toNativeSeparators(extraFonts->get(i,0)));
 	if( !cmd1.isEmpty() )
 		args.append( cmd1 );
 	// then add any final args and call gs
 	if ((EnableCMYK->isChecked()) && HaveTiffSep)
-		args.append( QString("-sOutputFile=%1").arg(QDir::convertSeparators(ScPaths::getTempFileDir()+"/sc.tif")) );
+		args.append( QString("-sOutputFile=%1").arg(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sc.tif")) );
 	else
-		args.append( QString("-sOutputFile=%1").arg(QDir::convertSeparators(ScPaths::getTempFileDir()+"/sc.png")) );
-	args.append( QDir::convertSeparators(ScPaths::getTempFileDir()+"/tmp.ps") );
+		args.append( QString("-sOutputFile=%1").arg(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sc.png")) );
+	args.append( QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/tmp.ps") );
 	args.append( "-c" );
 	args.append( "showpage" );
 	args.append( "-c" );
@@ -743,14 +743,14 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 	PrefsTable *extraFonts = pc->getTable("ExtraFontDirs");
 	const char sep = ScPaths::envPathSeparator;
 	if (extraFonts->getRowCount() >= 1)
-		cmd = QString("-sFONTPATH=%1").arg(QDir::convertSeparators(extraFonts->get(0,0)));
+		cmd = QString("-sFONTPATH=%1").arg(QDir::toNativeSeparators(extraFonts->get(0,0)));
 	for (int i = 1; i < extraFonts->getRowCount(); ++i)
-		cmd += QString("%1%2").arg(sep).arg(QDir::convertSeparators(extraFonts->get(i,0)));
+		cmd += QString("%1%2").arg(sep).arg(QDir::toNativeSeparators(extraFonts->get(i,0)));
 	if( !cmd.isEmpty() )
 		args1.append( cmd );
-	args1.append( QString("-sOutputFile=%1").arg(QDir::convertSeparators(ScPaths::getTempFileDir()+"/sc.tif")) );
+	args1.append( QString("-sOutputFile=%1").arg(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sc.tif")) );
 
-	args2.append( QDir::convertSeparators(ScPaths::getTempFileDir()+"/tmp.ps") );
+	args2.append( QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/tmp.ps") );
 	args2.append("-c");
 	args2.append("quit");
 
@@ -759,7 +759,7 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 	QStringList spots = usedSpots.keys();
 	args3.append( "-sDEVICE=tiffsep" );
 
-	args3.append( "-c" );
+//	args3.append( "-c" );
 	cmd = "<< /SeparationColorNames ";
 	QString allSeps ="[ /Cyan /Magenta /Yellow /Black ";
 	for (int sp = 0; sp < spots.count(); ++sp)
@@ -768,13 +768,22 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 	}
 	allSeps += "]";
 	cmd += allSeps + " /SeparationOrder [ /Cyan /Magenta /Yellow /Black] >> setpagedevice";
-	args3.append(cmd);
-
+	QFile fx(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sep.ps"));
+	if (fx.open(QIODevice::WriteOnly))
+	{
+		QTextStream tsx(&fx);
+		tsx << cmd;
+		fx.close();
+	}
 	args3.append("-f");
+	args3.append(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sep.ps"));
+//	args3.append(cmd);
+
+//	args3.append("-f");
 	QString gsExe(getShortPathName(prefsManager->ghostscriptExecutable()));
 	ret = System(gsExe, args1 + args3 + args2, ScPaths::getTempFileDir()+"/sc.tif.txt" );
 
-	QFile sepInfo(QDir::convertSeparators(ScPaths::getTempFileDir()+"/sc.tif.txt"));
+	QFile sepInfo(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sc.tif.txt"));
 	sepsToFileNum.clear();
 	if (sepInfo.open(QIODevice::ReadOnly))
 	{
@@ -803,9 +812,15 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 		{
 			args3.clear();
 			args3.append("-sDEVICE=tiffsep");
-			args3.append("-c");
-			args3.append("<< /SeparationColorNames "+allSeps+" /SeparationOrder [ "+currSeps+" ] >> setpagedevice");
+			QFile fx(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sep.ps"));
+			if (fx.open(QIODevice::WriteOnly))
+			{
+				QTextStream tsx(&fx);
+				tsx << QString("<< /SeparationColorNames "+allSeps+" /SeparationOrder [ "+currSeps+" ] >> setpagedevice");
+				fx.close();
+			}
 			args3.append("-f");
+			args3.append(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sep.ps"));
 			ret = System(gsExe, args1 + args3 + args2);
 			currSeps = "";
 			spc = 0;
@@ -815,9 +830,15 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 	{
 		args3.clear();
 		args3.append("-sDEVICE=tiffsep");
-		args3.append("-c");
-		args3.append("<< /SeparationColorNames "+allSeps+" /SeparationOrder [ "+currSeps+" ] >> setpagedevice");
+		QFile fx(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sep.ps"));
+		if (fx.open(QIODevice::WriteOnly))
+		{
+			QTextStream tsx(&fx);
+			tsx << QString("<< /SeparationColorNames "+allSeps+" /SeparationOrder [ "+currSeps+" ] >> setpagedevice");
+			fx.close();
+		}
 		args3.append("-f");
+		args3.append(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sep.ps"));
 		ret = System(gsExe, args1 + args3 + args2);
 	}
 	return ret;
@@ -942,10 +963,10 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 					q++;
 				}
 			}
-			CMSettings cms(doc, "", 0);
+			CMSettings cms(doc, "", Intent_Perceptual);
 			if (flagsVisible["Cyan"]->isChecked())
 			{
-				if (GsMinor < 54)
+				if ((GsMinor < 54) && (GsMajor < 9))
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.tif.Cyan.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
 				else
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.Cyan.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
@@ -961,7 +982,7 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			}
 			if (flagsVisible["Magenta"]->isChecked())
 			{
-				if (GsMinor < 54)
+				if ((GsMinor < 54) && (GsMajor < 9))
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.tif.Magenta.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
 				else
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.Magenta.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
@@ -977,7 +998,7 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			}
 			if (flagsVisible["Yellow"]->isChecked())
 			{
-				if (GsMinor < 54)
+				if ((GsMinor < 54) && (GsMajor < 9))
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.tif.Yellow.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
 				else
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.Yellow.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
@@ -1000,7 +1021,7 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 					if (checkBox && checkBox->isChecked())
 					{
 						QString fnam;
-						if (GsMinor < 54)
+						if ((GsMinor < 54) && (GsMajor < 9))
 							fnam = QString(ScPaths::getTempFileDir()+"/sc.tif.s%1.tif").arg(sepit.value());
 						else
 							fnam = QString(ScPaths::getTempFileDir()+"/sc.s%1.tif").arg(sepit.value());
@@ -1018,8 +1039,8 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			}
 			if (flagsVisible["Black"]->isChecked())
 			{
-				CMSettings cms(doc, "", 0);
-				if (GsMinor < 54)
+				CMSettings cms(doc, "", Intent_Perceptual);
+				if ((GsMinor < 54) && (GsMajor < 9))
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.tif.Black.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
 				else
 					loaderror = im.LoadPicture(ScPaths::getTempFileDir()+"/sc.Black.tif", 1, cms, false, false, ScImage::RGBData, 72, &mode);
@@ -1074,11 +1095,11 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 				{
 					QRgb alphaFF = qRgba(0,0,0,255);
 					QRgb alphaOO = qRgba(255,255,255,0);
-					cmsHTRANSFORM transCMYK = cmsCreateTransform(doc->DocPrinterProf, (COLORSPACE_SH(PT_CMYK)|CHANNELS_SH(4)|BYTES_SH(1)|DOSWAP_SH(1)|SWAPFIRST_SH(1)), doc->DocOutputProf, TYPE_BGRA_8, INTENT_RELATIVE_COLORIMETRIC, cmsFLAGS_LOWRESPRECALC);
+					ScColorTransform transCMYK = ScColorMgmtEngine::createTransform(doc->DocPrinterProf, Format_YMCK_8, doc->DocOutputProf, Format_BGRA_8, Intent_Relative_Colorimetric, Ctf_LowResPrecalc);
 					for( int yi=0; yi < h2; ++yi )
 					{
-						LPBYTE ptr = image.scanLine( yi );
-						cmsDoTransform(transCMYK, ptr, ptr, image.width());
+						uchar* ptr = image.scanLine( yi );
+						transCMYK.apply(ptr, ptr, image.width());
 						QRgb *q = (QRgb *) ptr;
 						for (int xi = 0; xi < image.width(); xi++, q++)
 						{
@@ -1096,7 +1117,6 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 								*q |= alphaFF;
 						}
 					}
-					cmsDeleteTransform (transCMYK);
 				}
 				else
 				{
@@ -1136,10 +1156,10 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 				{
 					QRgb alphaFF = qRgba(0,0,0,255);
 					QRgb alphaOO = qRgba(255,255,255,0);
-					cmsHTRANSFORM transCMYK = cmsCreateTransform(doc->DocPrinterProf, (COLORSPACE_SH(PT_CMYK)|CHANNELS_SH(4)|BYTES_SH(1)|DOSWAP_SH(1)|SWAPFIRST_SH(1)), doc->DocOutputProf, TYPE_BGRA_8, INTENT_RELATIVE_COLORIMETRIC, cmsFLAGS_LOWRESPRECALC);
+					ScColorTransform transCMYK = ScColorMgmtEngine::createTransform(doc->DocPrinterProf, Format_YMCK_8, doc->DocOutputProf, Format_BGRA_8, Intent_Relative_Colorimetric, Ctf_LowResPrecalc);
 					for (int y=0; y < h2; ++y )
 					{
-						LPBYTE ptr = image.scanLine( y );
+						uchar* ptr = image.scanLine( y );
 						f.read(imgc.data(), w2);
 						p = (uint *)image.scanLine( y );
 						for (int x=0; x < w2; x += 4 )
@@ -1159,7 +1179,7 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 							*p = qRgba(cyan, magenta, yellow, black);
 							p++;
 						}
-						cmsDoTransform(transCMYK, ptr, ptr, image.width());
+						transCMYK.apply(ptr, ptr, image.width());
 						QRgb *q = (QRgb *) ptr;
 						for (int xi = 0; xi < image.width(); xi++, q++)
 						{
@@ -1177,7 +1197,6 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 								*q |= alphaFF;
 						}
 					}
-					cmsDeleteTransform (transCMYK);
 				}
 				else
 				{
