@@ -52,7 +52,8 @@ for which a new license (GPL+exception) is in place.
 #include "updatemanager.h"
 #include "sclayer.h"
 
-#include CMS_INC
+#include "colormgmt/sccolorprofile.h"
+#include "colormgmt/sccolortransform.h"
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
@@ -143,6 +144,9 @@ public:
 	MassObservable<PageItem*> * itemsChanged() { return &m_itemsChanged; }
 	MassObservable<Page*>     * pagesChanged() { return &m_pagesChanged; }
 	MassObservable<QRectF>    * regionsChanged() { return &m_regionsChanged; }
+	
+	void invalidateAll();
+	void invalidateLayer(int layerID);
 	void invalidateRegion(QRectF region);
 	
 	// Add, delete and move pages
@@ -435,7 +439,11 @@ public:
 // 	bool isDefaultStyle( LineStyle& l ) const { return MLineStyles......; }
 
 	void getNamedResources(ResourceCollection& lists) const;
-	void replaceNamedResources(ResourceCollection& newNames);	
+	void replaceNamedResources(ResourceCollection& newNames);
+	bool styleExists(QString styleName);
+
+	QList<int> getSortedStyleList();
+	QList<int> getSortedCharStyleList();
 	
 	void redefineStyles(const StyleSet<ParagraphStyle>& newStyles, bool removeUnused=false);
 	/**
@@ -559,7 +567,7 @@ public:
 	/**
 	 * @brief Set the page margins. Current code uses current page only, also provide a (currently, TODO) option for this.
 	 */
-	bool changePageMargins(const double initialTop, const double initialBottom, const double initialLeft, const double initialRight, const double initialHeight, const double initialWidth, const double Height, const double width, const int orientation, const QString& pageSize, const int pageNumber=-1, const int pageType = 0);
+	bool changePageMargins(const double initialTop, const double initialBottom, const double initialLeft, const double initialRight, const double initialHeight, const double initialWidth, const double Height, const double width, const int orientation, const QString& pageSize, const int marginPreset, const bool moveObjects, const int pageNumber=-1, const int pageType = 0);
 	/**
 	 * @brief Recalculate the colors after CMS settings change. Update the items in the doc accordingly.
 	 */
@@ -685,11 +693,11 @@ public:
 	 */
 	void canvasMinMax(FPoint&, FPoint&);
 	
-	int OnPage(double x2, double  y2);
-	int OnPage(PageItem *currItem);
+	int  OnPage(double x2, double  y2);
+	int  OnPage(PageItem *currItem);
 	void GroupOnPage(PageItem *currItem);
-	//void reformPages(double& maxX, double& maxY, bool moveObjects = true);
 	void reformPages(bool moveObjects = true);
+	void fixItemPageOwner();
 	
 	/**
 	 * @brief Return the x or y offset for a page on the canvas
@@ -775,6 +783,7 @@ public:
 	void updateAllItemQColors();
 	//! @brief Some internal align tools
 	typedef enum {alignFirst, alignLast, alignPage, alignMargins, alignGuide, alignSelection } AlignTo;
+	typedef enum {alignByMoving, alignByResizing } AlignMethod;
 	void buildAlignItemList(Selection* customSelection=0);
 	bool startAlign();
 	void endAlign();
@@ -881,7 +890,7 @@ public:
 	/*! \brief Does this doc have any TOC setups and potentially a TOC to generate */
 	bool hasTOCSetup() { return !docToCSetups.empty(); }
 	//! \brief Get the closest guide to the given point
-	void getClosestGuides(double xin, double yin, double *xout, double *yout, int *GxM, int *GyM);
+	void getClosestGuides(double xin, double yin, double *xout, double *yout, int *GxM, int *GyM, Page* pg = NULL);
 	//! \brief Snap an item to the guides
 	void SnapToGuides(PageItem *currItem);
 	bool ApplyGuides(double *x, double *y);
@@ -1025,28 +1034,28 @@ public:
 	bool marginColored;
 	int GroupCounter;
 	CMSData CMSSettings;
-	cmsHPROFILE DocInputImageRGBProf;
-	cmsHPROFILE DocInputImageCMYKProf;
-	cmsHPROFILE DocInputRGBProf;
-	cmsHPROFILE DocInputCMYKProf;
-	cmsHPROFILE DocOutputProf;
-	cmsHPROFILE DocPrinterProf;
-	cmsHTRANSFORM stdTransRGBMon;
-	cmsHTRANSFORM stdTransCMYKMon;
-	cmsHTRANSFORM stdProof;
-	cmsHTRANSFORM stdTransImg;
-	cmsHTRANSFORM stdProofImg;
-	cmsHTRANSFORM stdProofImgCMYK;
-	cmsHTRANSFORM stdTransCMYK;
-	cmsHTRANSFORM stdProofCMYK;
-	cmsHTRANSFORM stdTransRGB;
-	cmsHTRANSFORM stdProofGC;
-	cmsHTRANSFORM stdProofCMYKGC;
+	ScColorProfile DocInputImageRGBProf;
+	ScColorProfile DocInputImageCMYKProf;
+	ScColorProfile DocInputRGBProf;
+	ScColorProfile DocInputCMYKProf;
+	ScColorProfile DocOutputProf;
+	ScColorProfile DocPrinterProf;
+	ScColorTransform stdTransRGBMon;
+	ScColorTransform stdTransCMYKMon;
+	ScColorTransform stdProof;
+	ScColorTransform stdTransImg;
+	ScColorTransform stdProofImg;
+	ScColorTransform stdProofImgCMYK;
+	ScColorTransform stdTransCMYK;
+	ScColorTransform stdProofCMYK;
+	ScColorTransform stdTransRGB;
+	ScColorTransform stdProofGC;
+	ScColorTransform stdProofCMYKGC;
 	bool BlackPoint;
 	bool SoftProofing;
 	bool Gamut;
-	int  IntentColors;
-	int  IntentImages;
+	eRenderIntent IntentColors;
+	eRenderIntent IntentImages;
 	bool HasCMS;
 	QMap<QString,QString> JavaScripts;
 	int TotalItems;
@@ -1156,6 +1165,7 @@ public slots:
 	void itemSelection_ClearItem(Selection* customSelection=0);
 	//! Delete the items in the current selection. When force is true, we do not warn the user and make SE happy too. Force is used from @sa Page::restorePageItemCreation
 	void itemSelection_DeleteItem(Selection* customSelection=0, bool forceDeletion=false);
+	void itemSelection_SetItemTextReversed(bool reversed);
 	void itemSelection_SetItemFillTransparency(double t);
 	void itemSelection_SetItemLineTransparency(double t);
 	void itemSelection_SetItemFillBlend(int t);
@@ -1172,22 +1182,26 @@ public slots:
 	void itemSelection_SetImageOffset(double x, double y, Selection* customSelection=0);
 	void itemSelection_SetImageScale(double x, double y, Selection* customSelection=0);
 	void itemSelection_SetImageScaleAndOffset(double ox, double oy, double sx, double sy, Selection* customSelection=0);
-	void itemSelection_AlignLeftOut(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignRightOut(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignBottomIn(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignRightIn(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignBottomOut(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignCenterHor(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignLeftIn(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignCenterVer(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignTopOut(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_AlignTopIn(AlignTo currAlignTo, double guidePosition);
-	void itemSelection_DistributeDistH(bool usingDistance=false, double distance=0.0);
+	void itemSelection_AlignItemLeft(int i, double newX, AlignMethod how);
+	void itemSelection_AlignItemRight(int i, double newX, AlignMethod how);
+	void itemSelection_AlignItemTop(int i, double newY, AlignMethod how);
+	void itemSelection_AlignItemBottom(int i, double newY, AlignMethod how);
+	void itemSelection_AlignLeftOut(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignRightOut(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignBottomIn(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignRightIn(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignBottomOut(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignCenterHor(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignLeftIn(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignCenterVer(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignTopOut(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_AlignTopIn(AlignTo currAlignTo, AlignMethod currAlignMethod, double guidePosition);
+	void itemSelection_DistributeDistH(bool usingDistance=false, double distance=0.0, bool reverseDistribute=false);
 	void itemSelection_DistributeAcrossPage(bool useMargins=false);
 	void itemSelection_DistributeRight();
 	void itemSelection_DistributeBottom();
 	void itemSelection_DistributeCenterH();
-	void itemSelection_DistributeDistV(bool usingDistance=false, double distance=0.0);
+	void itemSelection_DistributeDistV(bool usingDistance=false, double distance=0.0, bool reverseDistribute=false);
 	void itemSelection_DistributeDownPage(bool useMargins=false);
 	void itemSelection_DistributeLeft();
 	void itemSelection_DistributeCenterV();
