@@ -19,7 +19,7 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 
 
-SMLineStyle::SMLineStyle() : StyleItem(), doc_(0), widget_(0), twidget_(0), selectionIsDirty_(false)
+SMLineStyle::SMLineStyle() : StyleItem(), doc_(0), widget_(0), twidget_(0), selectionIsDirty_(false), unitRatio_(1.0)
 {
 	
 }
@@ -54,6 +54,11 @@ void SMLineStyle::setCurrentDoc(ScribusDoc *doc)
 	{
 		tmpLines = doc_->MLineStyles;
 		selection_.clear();
+		if (widget_)
+		{
+			if (unitRatio_ != doc_->unitRatio())
+				unitChange();
+		}
 	}
 	else
 	{
@@ -222,7 +227,11 @@ void SMLineStyle::apply()
 	doc_->MLineStyles = tmpLines;
 	QMap<QString, QString> replacement;
 	for (int i = 0; i < deleted_.count(); ++i)
+	{
+		if (deleted_[i].first == deleted_[i].second)
+			continue;
 		replacement[deleted_[i].first] = deleted_[i].second;
+	}
 
 	deleted_.clear();
 
@@ -342,7 +351,7 @@ void SMLineStyle::nameChanged(const QString &newName)
 	QList<RemoveItem>::iterator it;
 	for (it = deleted_.begin(); it != deleted_.end(); ++it)
 	{
-		if ((*it).second == oldName)
+		if (it->second == oldName)
 		{
 			oldName = (*it).first;
 			deleted_.erase(it);
@@ -350,7 +359,8 @@ void SMLineStyle::nameChanged(const QString &newName)
 		}
 	}
 
-	deleted_.append(RemoveItem(oldName, newName));
+	if (oldName != newName)
+		deleted_.append(RemoveItem(oldName, newName));
 }
 
 void SMLineStyle::changeEvent(QEvent *e)
@@ -368,7 +378,10 @@ void SMLineStyle::languageChange()
 
 void SMLineStyle::unitChange()
 {
-
+	double oldRatio = unitRatio_;
+	unitRatio_ = doc_->unitRatio();
+	if (widget_)
+		widget_->unitChange(oldRatio, unitRatio_, doc_->unitIndex());
 }
 
 void SMLineStyle::setupConnections()
